@@ -20,7 +20,7 @@
 #ifndef BIRTHDAYDLG_H
 #define BIRTHDAYDLG_H
 
-#include <kalarmcal/kaevent.h>
+#include <KAlarmCal/KAEvent>
 
 #include <QDialog>
 #include <QVector>
@@ -67,7 +67,7 @@ class BirthdayDlg : public QDialog
         FontColourButton*     mFontColourButton;
         CheckBox*             mConfirmAck;
         LateCancelSelector*   mLateCancel;
-        SpecialActionsButton* mSpecialActionsButton{nullptr};
+        SpecialActionsButton* mSpecialActionsButton {nullptr};
         RepetitionButton*     mSubRepetition;
         QDialogButtonBox*     mButtonBox;
         QString               mPrefixText;   // last entered value of prefix text
