@@ -27,7 +27,7 @@
 #include "kamail.h"
 #include "preferences.h"
 
-#include <kalarmcal/kaevent.h>
+#include <KAlarmCal/KAEvent>
 
 #include <QApplication>
 #include <QPointer>
@@ -98,8 +98,8 @@ class KAlarmApp : public QApplication
                                          uint mailFromID = 0, const KCalendarCore::Person::List& mailAddresses = KCalendarCore::Person::List(),
                                          const QString& mailSubject = QString(),
                                          const QStringList& mailAttachments = QStringList());
-        bool               dbusTriggerEvent(const EventId& eventID)   { return dbusHandleEvent(eventID, EVENT_TRIGGER); }
-        bool               dbusDeleteEvent(const EventId& eventID)    { return dbusHandleEvent(eventID, EVENT_CANCEL); }
+        bool               dbusTriggerEvent(const EventId& eventID)   { return dbusHandleEvent(eventID, QueuedAction::Trigger); }
+        bool               dbusDeleteEvent(const EventId& eventID)    { return dbusHandleEvent(eventID, QueuedAction::Cancel); }
         QString            dbusList();
 
     public Q_SLOTS:
@@ -133,7 +133,9 @@ class KAlarmApp : public QApplication
         void               slotFeb29TypeChanged(Feb29Type);
         void               slotResourcesTimeout();
         void               slotResourcesCreated();
+        void               slotEditAlarmById();
         void               checkWritableCalendar();
+        void               promptArchivedCalendar();
         void               slotMessageFontChanged(const QFont&);
         void               setArchivePurgeDays();
         void               slotResourceAdded(const Resource&);
@@ -142,11 +144,19 @@ class KAlarmApp : public QApplication
         void               slotCommandExited(ShellProcess*);
 
     private:
-        enum EventFunc
+        // Actions to execute in processQueue(). May be OR'ed together.
+        enum class QueuedAction
         {
-            EVENT_HANDLE,    // if the alarm is due, execute it and then reschedule it
-            EVENT_TRIGGER,   // execute the alarm regardless, and then reschedule it if it's already due
-            EVENT_CANCEL     // delete the alarm
+            // Action to execute
+            ActionMask = 0x07,  // bit mask to extract action to execute
+            Handle     = 0x01,  // if the alarm is due, execute it and then reschedule it
+            Trigger    = 0x02,  // execute the alarm regardless, and then reschedule it if it's already due
+            Cancel     = 0x03,  // delete the alarm
+            Edit       = 0x04,  // edit an alarm (command line option)
+            List       = 0x05,  // list all alarms (command line option)
+            // Modifier flags
+            FindId     = 0x10,  // search all resources for unique event ID
+            Exit       = 0x20   // exit application after executing action
         };
         struct ProcData
         {
@@ -171,27 +181,27 @@ class KAlarmApp : public QApplication
         };
         struct ActionQEntry
         {
-            ActionQEntry(EventFunc f, const EventId& id) : function(f), eventId(id) { }
-            ActionQEntry(const KAEvent& e, EventFunc f = EVENT_HANDLE) : function(f), event(e) { }
+            ActionQEntry(QueuedAction a, const EventId& id) : action(a), eventId(id) { }
+            ActionQEntry(const KAEvent& e, QueuedAction a = QueuedAction::Handle) : action(a), event(e) { }
             ActionQEntry() { }
-            EventFunc  function;
-            EventId    eventId;
-            KAEvent    event;
+            QueuedAction  action;
+            EventId       eventId;
+            KAEvent       event;
         };
 
         KAlarmApp(int& argc, char** argv);
         bool               initialiseTimerResources();
         int                activateInstance(const QStringList& args, const QString& workingDirectory, QString* outputText);
-        bool               initCheck(bool calendarOnly = false, bool waitForCollection = false, Akonadi::Collection::Id = -1);
-        bool               waitUntilPopulated(ResourceId, int timeout);
+        bool               initCheck(bool calendarOnly = false);
         bool               quitIf(int exitCode, bool force = false);
         void               createOnlyMainWindow();
         bool               checkSystemTray();
         void               startProcessQueue();
         void               setResourcesTimeout();
+        void               checkArchivedCalendar();
         void               queueAlarmId(const KAEvent&);
-        bool               dbusHandleEvent(const EventId&, EventFunc);
-        bool               handleEvent(const EventId&, EventFunc, bool findUniqueId = false);
+        bool               dbusHandleEvent(const EventId&, QueuedAction);
+        bool               handleEvent(const EventId&, QueuedAction, bool findUniqueId = false);
         int                rescheduleAlarm(KAEvent&, const KAAlarm&, bool updateCalAndDisplay,
                                            const KADateTime& nextDt = KADateTime());
         bool               cancelAlarm(KAEvent&, KAAlarm::Type, bool updateCalAndDisplay);
@@ -208,34 +218,36 @@ class KAlarmApp : public QApplication
         void               clearEventCommandError(const KAEvent&, KAEvent::CmdErrType) const;
         ProcData*          findCommandProcess(const QString& eventId) const;
 
-        static KAlarmApp*  mInstance;              // the one and only KAlarmApp instance
-        static int         mActiveCount;           // number of active instances without main windows
-        static int         mFatalError;            // a fatal error has occurred - just wait to exit
-        static QString     mFatalMessage;          // fatal error message to output
-        bool               mInitialised{false};    // initialisation complete: ready to process execution queue
-        bool               mRedisplayAlarms{false}; // need to redisplay alarms when collection tree fetched
-        bool               mQuitting{false};       // a forced quit is in progress
-        bool               mReadOnly{false};       // only read-only access to calendars is needed
-        QString            mActivateArg0;          // activate()'s first arg the first time it was called
-        DBusHandler*       mDBusHandler;           // the parent of the main DCOP receiver object
-        TrayWindow*        mTrayWindow{nullptr};   // active system tray icon
-        QTimer*            mAlarmTimer{nullptr};   // activates KAlarm when next alarm is due
-        QColor             mPrefsArchivedColour;   // archived alarms text colour
-        int                mArchivedPurgeDays{-1}; // how long to keep archived alarms, 0 = don't keep, -1 = keep indefinitely
-        int                mPurgeDaysQueued{-1};   // >= 0 to purge the archive calendar from KAlarmApp::processLoop()
-        QVector<ResourceId> mPendingPurges;        // new resources which may need to be purged when populated
-        QList<ProcData*>   mCommandProcesses;      // currently active command alarm processes
-        QQueue<ActionQEntry> mActionQueue;         // queued commands and actions
-        int                mPendingQuitCode;       // exit code for a pending quit
-        bool               mPendingQuit{false};    // quit once the DCOP command and shell command queues have been processed
-        bool               mCancelRtcWake{false};  // cancel RTC wake on quitting
-        bool               mProcessingQueue{false}; // a mActionQueue entry is currently being processed
-        bool               mNoSystemTray;          // no system tray exists
-        bool               mOldShowInSystemTray;   // showing in system tray was selected
-        bool               mAlarmsEnabled{true};   // alarms are enabled
-        bool               mKOrganizerEnabled;     // KOrganizer options are enabled (korganizer exists)
-        bool               mWindowFocusBroken;     // keyboard focus transfer between windows doesn't work
-        bool               mResourcesTimedOut{false}; // timeout has expired for populating resources
+        static KAlarmApp*  mInstance;               // the one and only KAlarmApp instance
+        static int         mActiveCount;            // number of active instances without main windows
+        static int         mFatalError;             // a fatal error has occurred - just wait to exit
+        static QString     mFatalMessage;           // fatal error message to output
+        QString            mCommandOption;          // command option used on command line
+        bool               mInitialised {false};    // initialisation complete: ready to process execution queue
+        bool               mRedisplayAlarms {false}; // need to redisplay alarms when collection tree fetched
+        bool               mQuitting {false};       // a forced quit is in progress
+        bool               mReadOnly {false};       // only read-only access to calendars is needed
+        QString            mActivateArg0;           // activate()'s first arg the first time it was called
+        DBusHandler*       mDBusHandler;            // the parent of the main DCOP receiver object
+        TrayWindow*        mTrayWindow {nullptr};   // active system tray icon
+        QTimer*            mAlarmTimer {nullptr};   // activates KAlarm when next alarm is due
+        QColor             mPrefsArchivedColour;    // archived alarms text colour
+        int                mArchivedPurgeDays {-1}; // how long to keep archived alarms, 0 = don't keep, -1 = keep indefinitely
+        int                mPurgeDaysQueued {-1};   // >= 0 to purge the archive calendar from KAlarmApp::processLoop()
+        QVector<ResourceId> mPendingPurges;         // new resources which may need to be purged when populated
+        QList<ProcData*>   mCommandProcesses;       // currently active command alarm processes
+        QQueue<ActionQEntry> mActionQueue;          // queued commands and actions
+        int                mEditingCmdLineAlarm {0}; // whether currently editing alarm specified on command line
+        int                mPendingQuitCode;        // exit code for a pending quit
+        bool               mPendingQuit {false};    // quit once the DCOP command and shell command queues have been processed
+        bool               mCancelRtcWake {false};   // cancel RTC wake on quitting
+        bool               mProcessingQueue {false}; // a mActionQueue entry is currently being processed
+        bool               mNoSystemTray;           // no system tray exists
+        bool               mOldShowInSystemTray;    // showing in system tray was selected
+        bool               mAlarmsEnabled {true};   // alarms are enabled
+        bool               mKOrganizerEnabled;      // KOrganizer options are enabled (korganizer exists)
+        bool               mWindowFocusBroken;      // keyboard focus transfer between windows doesn't work
+        bool               mResourcesTimedOut {false}; // timeout has expired for populating resources
 };
 
 inline KAlarmApp* theApp()  { return KAlarmApp::instance(); }
