@@ -21,21 +21,23 @@
 #include "preferences.h"
 
 #include "kalarm.h"
-#include "functions.h"
 #include "kamail.h"
-#include "messagebox.h"
+#include "lib/desktop.h"
+#include "lib/messagebox.h"
 #include "kalarm_debug.h"
 
-#include <kalarmcal/identities.h>
+#include <KAlarmCal/Identities>
 
-#include <KIdentityManagement/kidentitymanagement/identity.h>
-#include <KIdentityManagement/kidentitymanagement/identitymanager.h>
+#include <KIdentityManagement/Identity>
+#include <KIdentityManagement/IdentityManager>
 #include <KHolidays/HolidayRegion>
 
 #include <KSharedConfig>
-#include <kconfiggroup.h>
-#include <kmessagebox.h>
+#include <KConfigGroup>
+#include <KMessageBox>
 
+#include <QFile>
+#include <QDir>
 #include <QStandardPaths>
 
 #include <time.h>
@@ -115,7 +117,7 @@ Preferences::Preferences()
 */
 int Preferences::autoHideSystemTray()
 {
-    if(noAutoHideSystemTrayDesktops().contains(KAlarm::currentDesktopIdentityName()))
+    if (noAutoHideSystemTrayDesktops().contains(Desktop::currentIdentityName()))
         return 0;   // never hide
     return self()->mBase_AutoHideSystemTray;
 }
@@ -127,7 +129,7 @@ int Preferences::autoHideSystemTray()
 */
 void Preferences::setAutoHideSystemTray(int timeout)
 {
-    if(noAutoHideSystemTrayDesktops().contains(KAlarm::currentDesktopIdentityName()))
+    if (noAutoHideSystemTrayDesktops().contains(Desktop::currentIdentityName()))
         return;
     self()->setBase_AutoHideSystemTray(timeout);
 }
