@@ -1,7 +1,7 @@
 /*
  *  resourcedatamodelbase.cpp  -  base for models containing calendars and events
  *  Program:  kalarm
- *  Copyright © 2007-2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2007-2020 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,18 +20,19 @@
 
 #include "resourcedatamodelbase.h"
 
+#include "resources.h"
+
 #include "alarmtime.h"
 #include "mainwindow.h"
-#include "messagebox.h"
 #include "preferences.h"
-#include "resources/resource.h"
+#include "lib/messagebox.h"
 #include "kalarm_debug.h"
 
-#include <kalarmcal/alarmtext.h>
-#include <kalarmcal/kaevent.h>
+#include <KAlarmCal/AlarmText>
+#include <KAlarmCal/KAEvent>
 
 #include <KLocalizedString>
-#include <kcolorutils.h>
+#include <KColorUtils>
 
 #include <QModelIndex>
 #include <QUrl>
@@ -156,6 +157,9 @@ QVariant ResourceDataModelBase::headerData(int section, Qt::Orientation orientat
     return QVariant();
 }
 
+/******************************************************************************
+* Return whether resourceData() or eventData() handle a role.
+*/
 bool ResourceDataModelBase::roleHandled(int role) const
 {
     switch (role)
@@ -169,6 +173,8 @@ bool ResourceDataModelBase::roleHandled(int role) const
         case Qt::SizeHintRole:
         case Qt::AccessibleTextRole:
         case Qt::ToolTipRole:
+        case ItemTypeRole:
+        case ResourceIdRole:
         case BaseColourRole:
         case TimeDisplayRole:
         case SortRole:
@@ -191,7 +197,7 @@ bool ResourceDataModelBase::roleHandled(int role) const
 */
 QVariant ResourceDataModelBase::resourceData(int& role, const Resource& resource, bool& handled) const
 {
-    if (roleHandled(role))   // Ensure that resourceDataHandles() is coded correctly
+    if (roleHandled(role))   // Ensure that roleHandled() is coded correctly
     {
         handled = true;
         switch (role)
@@ -206,12 +212,16 @@ QVariant ResourceDataModelBase::resourceData(int& role, const Resource& resource
                 const QColor colour = resource.backgroundColour();
                 if (colour.isValid())
                     return colour;
-                break;
+                break;    // use base model background colour
             }
             case Qt::ForegroundRole:
                 return resource.foregroundColour();
             case Qt::ToolTipRole:
                 return tooltip(resource, CalEvent::ACTIVE | CalEvent::ARCHIVED | CalEvent::TEMPLATE);
+            case ItemTypeRole:
+                return static_cast<int>(Type::Resource);
+            case ResourceIdRole:
+                return resource.id();
             default:
                 break;
         }
@@ -227,13 +237,20 @@ QVariant ResourceDataModelBase::resourceData(int& role, const Resource& resource
 QVariant ResourceDataModelBase::eventData(int role, int column, const KAEvent& event,
                                           const Resource& resource, bool& handled) const
 {
-    if (roleHandled(role))   // Ensure that eventDataHandles() is coded correctly
+    if (roleHandled(role))   // Ensure that roleHandled() is coded correctly
     {
         handled = true;
         bool calendarColour = false;
 
-        if (role == Qt::WhatsThisRole)
-            return whatsThisText(column);
+        switch (role)
+        {
+            case Qt::WhatsThisRole:
+                return whatsThisText(column);
+            case ItemTypeRole:
+                return static_cast<int>(Type::Event);
+            default:
+                break;
+        }
         if (!event.isValid())
             return QVariant();
         switch (role)
@@ -474,24 +491,17 @@ QString ResourceDataModelBase::tooltip(const Resource& resource, CalEvent::Types
     const bool    inactive = !(resource.enabledTypes() & types);
     const QString readonly = readOnlyTooltip(resource);
     const bool    writable = readonly.isEmpty();
-//TODO: should the above line be   = resource.isWritable() ?
     const QString disabled = i18nc("@info", "Disabled");
-    if (inactive  &&  !writable)
-        return xi18nc("@info:tooltip",
-                     "%1"
-                     "<nl/>%2: <filename>%3</filename>"
-                     "<nl/>%4, %5",
-                     name, type, locn, disabled, readonly);
     if (inactive  ||  !writable)
         return xi18nc("@info:tooltip",
-                     "%1"
-                     "<nl/>%2: <filename>%3</filename>"
-                     "<nl/>%4",
-                     name, type, locn, (inactive ? disabled : readonly));
+                      "%1"
+                      "<nl/>%2: <filename>%3</filename>"
+                      "<nl/>%4",
+                      name, type, locn, (inactive ? disabled : readonly));
     return xi18nc("@info:tooltip",
-                 "%1"
-                 "<nl/>%2: <filename>%3</filename>",
-                 name, type, locn);
+                  "%1"
+                  "<nl/>%2: <filename>%3</filename>",
+                  name, type, locn);
 }
 
 /******************************************************************************
@@ -602,4 +612,25 @@ void ResourceDataModelBase::handleResourceMessage(ResourceType::MessageType type
         KAMessageBox::informationList(MainWindow::mainMainWindow(), message, {details});
 }
 
+bool ResourceDataModelBase::isMigrationComplete() const
+{
+    return mMigrationStatus == 1;
+}
+
+bool ResourceDataModelBase::isMigrating() const
+{
+    return mMigrationStatus == 0;
+}
+
+void ResourceDataModelBase::setMigrationInitiated(bool started)
+{
+    mMigrationStatus = (started ? 0 : -1);
+}
+
+void ResourceDataModelBase::setMigrationComplete()
+{
+    mMigrationStatus = 1;
+    Resources::notifyResourcesMigrated();
+}
+
 // vim: et sw=4:
