@@ -1,7 +1,7 @@
 /*
  *  resourceselector.cpp  -  calendar resource selection widget
  *  Program:  kalarm
- *  Copyright © 2006-2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2006-2020 David Jarvie <djarvie@kde.org>
  *  Based on KOrganizer's ResourceView class and KAddressBook's ResourceSelection class,
  *  Copyright (C) 2003,2004 Cornelius Schumacher <schumacher@kde.org>
  *  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
@@ -25,20 +25,22 @@
 #include "resourceselector.h"
 
 #include "alarmcalendar.h"
-#include "autoqpointer.h"
-#include "akonadiresourcecreator.h"
-#include "calendarmigrator.h"
 #include "kalarmapp.h"
-#include "messagebox.h"
-#include "packedlayout.h"
 #include "preferences.h"
+#include "resources/akonadidatamodel.h"
+#include "resources/akonadiresourcecreator.h"
+#include "resources/akonadiresourcemigrator.h"
+#include "resources/datamodel.h"
 #include "resources/resources.h"
 #include "resources/resourcemodel.h"
+#include "lib/autoqpointer.h"
+#include "lib/messagebox.h"
+#include "lib/packedlayout.h"
 #include "kalarm_debug.h"
 
 #include <KLocalizedString>
-#include <kactioncollection.h>
-#include <ktoggleaction.h>
+#include <KActionCollection>
+#include <KToggleAction>
 
 #include <QAction>
 #include <QLabel>
@@ -70,7 +72,7 @@ ResourceSelector::ResourceSelector(QWidget* parent)
     topLayout->addWidget(mAlarmType);
     // No spacing between combo box and listview.
 
-    ResourceFilterCheckListModel* model = ResourceFilterCheckListModel::create<AkonadiModel>(this);
+    ResourceFilterCheckListModel* model = DataModel::createResourceFilterCheckListModel(this);
     mListView = new ResourceView(model, this);
     connect(mListView->selectionModel(), &QItemSelectionModel::selectionChanged, this, &ResourceSelector::selectionChanged);
     mListView->setContextMenuPolicy(Qt::CustomContextMenu);
@@ -99,9 +101,6 @@ ResourceSelector::ResourceSelector(QWidget* parent)
     connect(mEditButton, &QPushButton::clicked, this, &ResourceSelector::editResource);
     connect(mDeleteButton, &QPushButton::clicked, this, &ResourceSelector::removeResource);
 
-    connect(Resources::instance(), &Resources::resourceRemoved,
-                             this, &ResourceSelector::selectionChanged);
-
     connect(mAlarmType, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), this, &ResourceSelector::alarmTypeSelected);
     QTimer::singleShot(0, this, SLOT(alarmTypeSelected()));
 
@@ -168,14 +167,14 @@ void ResourceSelector::reinstateAlarmTypeScrollBars()
 */
 void ResourceSelector::addResource()
 {
-    AkonadiResourceCreator* creator = new AkonadiResourceCreator(mCurrentAlarmType, this);
-    connect(creator, &AkonadiResourceCreator::resourceAdded, this, &ResourceSelector::slotResourceAdded);
+    ResourceCreator* creator = DataModel::createResourceCreator(mCurrentAlarmType, this);
+    connect(creator, &ResourceCreator::resourceAdded, this, &ResourceSelector::slotResourceAdded);
     creator->createResource();
 }
 
 /******************************************************************************
-* Called when a collection is added to the AkonadiModel, after being created
-* by addResource().
+* Called when a resource is added to the calendar data model, after being
+* created by addResource().
 */
 void ResourceSelector::slotResourceAdded(Resource& resource, CalEvent::Type alarmType)
 {
@@ -183,9 +182,9 @@ void ResourceSelector::slotResourceAdded(Resource& resource, CalEvent::Type alar
     resource.setEnabled(types);
     if (!(types & alarmType))
     {
-        // The user has selected alarm types for the resource
-        // which don't include the currently displayed type.
-        // Show a collection list which includes a selected type.
+        // The user has selected alarm types for the resource which don't
+        // include the currently displayed type.
+        // Show a resource list which includes a selected type.
         int index = -1;
         if (types & CalEvent::ACTIVE)
             index = 0;
@@ -215,10 +214,10 @@ void ResourceSelector::editResource()
 */
 void ResourceSelector::updateResource()
 {
-    const Resource resource = currentResource();
+    Resource resource = currentResource();
     if (!resource.isValid())
         return;
-    CalendarMigrator::updateToCurrentFormat(resource, true, this);
+    DataModel::updateCalendarToCurrentFormat(resource, true, this);
 }
 
 /******************************************************************************
@@ -229,6 +228,7 @@ void ResourceSelector::removeResource()
     Resource resource = currentResource();
     if (!resource.isValid())
         return;
+    qCDebug(KALARM_LOG) << "ResourceSelector::removeResource:" << resource.displayName();
     const QString name = resource.configName();
     // Check if it's the standard or only resource for at least one type.
     const CalEvent::Types allTypes      = resource.alarmTypes();
@@ -399,9 +399,9 @@ void ResourceSelector::contextMenuRequested(const QPoint& viewportPos)
 */
 void ResourceSelector::reloadResource()
 {
-    const Resource resource = currentResource();
+    Resource resource = currentResource();
     if (resource.isValid())
-        AkonadiModel::instance()->reloadResource(resource);
+        DataModel::reload(resource);
 }
 
 /******************************************************************************
